from setuptools import setup

setup(name='rainel',
      version='1.1',
      description='Gaussian and Binomial distributions',
      packages=['rainel'],
      author='Felipe Rainel',
      author_email= 'raineldias88@gmail.com',
      zip_safe=False)
